==> eventmachine-0.7.0.gem: ext/project.h <==
/*****************************************************************************

$Id: project.h 265 2006-10-05 19:07:45Z blackhedd $

File:     project.h
Date:     06Apr06

Copyright (C) 2006 by Francis Cianfrocca. All Rights Reserved.
Gmail: garbagecat20

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*****************************************************************************/


#ifndef __Project__H_
#define __Project__H_


#ifdef OS_WIN32
#pragma warning(disable:4786)
#endif

#include <iostream>
#include <map>
#include <vector>
#include <deque>
#include <string>
#include <sstream>
#include <stdexcept>


#ifdef OS_UNIX
#include <signal.h>
#include <netdb.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/un.h>
#include <assert.h>
#include <unistd.h>
#include <fcntl.h>
#include <errno.h>
#include <netinet/in.h>
#include <netinet/tcp.h>
#include <arpa/inet.h>
typedef int SOCKET;
#define closesocket close
#define INVALID_SOCKET -1
#define SOCKET_ERROR -1
#ifdef OS_SOLARIS8
#define INADDR_NONE ((unsigned long)-1)
#endif
#endif


#ifdef OS_WIN32
#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#include <winsock.h>
#include <rpc.h>
#include <fcntl.h>
#include <assert.h>
typedef int socklen_t;
#endif


using namespace std;

#ifdef WITH_SSL
#include <openssl/ssl.h>
#include <openssl/err.h>
#endif

#include "binder.h"
#include "em.h"
#include "sigs.h"
#include "ed.h"
#include "files.h"
#include "page.h"
#include "ssl.h"




#endif // __Project__H_

==> eventmachine-0.8.0.gem: ext/project.h <==
/*****************************************************************************

$Id: project.h 401 2007-07-11 12:54:06Z blackhedd $

File:     project.h
Date:     06Apr06

Copyright (C) 2006-07 by Francis Cianfrocca. All Rights Reserved.
Gmail: blackhedd

This program is free software; you can redistribute it and/or modify
it under the terms of either: 1) the GNU General Public License
as published by the Free Software Foundation; either version 2 of the
License, or (at your option) any later version; or 2) Ruby's License.

See the file COPYING for complete licensing information.

*****************************************************************************/


#ifndef __Project__H_
#define __Project__H_


#ifdef OS_WIN32
#pragma warning(disable:4786)
#endif

#include <iostream>
#include <map>
#include <set>
#include <vector>
#include <deque>
#include <string>
#include <sstream>
#include <stdexcept>


#ifdef OS_UNIX
#include <signal.h>
#include <netdb.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/un.h>
#include <sys/resource.h>
#include <sys/wait.h>
#include <assert.h>
#include <unistd.h>
#include <fcntl.h>
#include <errno.h>
#include <netinet/in.h>
#include <netinet/tcp.h>
#include <arpa/inet.h>
#include <pwd.h>
typedef int SOCKET;
#define closesocket close
#define INVALID_SOCKET -1
#define SOCKET_ERROR -1
#ifdef OS_SOLARIS8
#include <strings.h>
#include <sys/un.h>
#ifndef AF_LOCAL
#define AF_LOCAL AF_UNIX
#endif
// The ff is superfluous on Solaris > 7. Thanks to Brett Eisenberg.
//#define INADDR_NONE ((unsigned long)-1)
#endif
#endif


#ifdef OS_WIN32
#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#include <winsock.h>
#include <rpc.h>
#include <fcntl.h>
#include <assert.h>
typedef int socklen_t;
typedef int pid_t;
#endif


using namespace std;

#ifdef WITH_SSL
#include <openssl/ssl.h>
#include <openssl/err.h>
#endif

#ifdef HAVE_EPOLL
#include <sys/epoll.h>
#endif

#include "binder.h"
#include "em.h"
#include "epoll.h"
#include "sigs.h"
#include "ed.h"
#include "files.h"
#include "page.h"
#include "ssl.h"
#include "eventmachine.h"




#endif // __Project__H_
